package PNI::Node::Tk;

our $VERSION = '0.15';

1
__END__

=head1 NAME

PNI::Node::Tk - PNI node collection

=head1 DESCRIPTION

PNI node collection to access the Tk graphical user interface toolkit.

=head1 NODES

=over 4

=item L<PNI::Node::Tk::Canvas>

=item L<PNI::Node::Tk::Canvas::Rectangle>

=item L<PNI::Node::Tk::Canvas::Text>

=item L<PNI::Node::Tk::MainWindow>

=back

=cut

